#' Calculation of Feature Importance
#'
#' @param obj A class DecTree object.
#' @param print = 1 to print the result
#'
#' @examples
#' Xc <- data.frame(x1=as.factor(square$x1),x2=as.factor(square$x2))
#' res1 <- DecTree( square$Class4, Xc, minnobs=1, eps=0, method=4, print=3
#'                  , plot=0, title="square: categorical y, categorical X" )
#' fi <- feature_imp_dt( res1, print=1 )
#'
#' @export
#'

feature_imp_dt <- function( obj, print=0 ){
 # calculation of feature importance
 # Shin-ichi Mayekawa
 # 20231016
 # minobs -> minnobs: 20231229
 # majestic<0: 20240417
 #

 # DecTree object
 if( class(obj) == "DecTree" ){
  node=obj$node
  xname=obj$xname
  yname=obj$yname
  if( length(yname) == 0 ) yname=obj$yname2
  nx=obj$nx
  majestic=obj$majestic
  rm(obj)
 }
 else{
  cat("\nerror1:(feature_imp_dt) The input object is not a DecTree object.\n")
  stop()
 }

 if( majestic < 0 ){
   cat(
  "\nerror1:(feature_imp_dt) Cannot calculate importance when majestic < 0.\n")
   stop()

 }

 # feature importance
 nobs=as.numeric( get_valLL(node,"nobs")[,"_v_1"] )
 var=as.numeric( get_valLL(node,"j")[,"_v_1"] )
 scoreimp=as.numeric( get_valLL(node,"scoreimp")[,"_v_1"] )
 locnz=which(var != 0)
 nobs=nobs[locnz]
 var=var[locnz]
 scoreimp=scoreimp[locnz]
 # importance=scoreimp/nobs # 20231005
 importance=scoreimp
 # Print(var,nobs, importance)
 temp=xtabs(importance~var)
 temp=temp/sum(temp)


 # Print(temp,names(temp))
 fimport=numeric(nx)
 fimport[as.numeric(names(temp))]=temp
 names(fimport)=xname

 if( print ){
  Print(fimport)
 }

 return( fimport )

} # end of feature_imp_dt


