#' 個体の分類
#'
#' 説明変数行列を与えたときに各個体を終端ノードに分類する。 \cr
#' English help file: \link[lazy.tree]{predict_dt}
#'
#' @usage predict_dt( X, obj )
#'
#' @param X 説明変数行列のデータフレーム
#' @param obj \code{DecTree} RecTree クラスのオブジェクト
#'
#' @examples
#' Xc=as.data.frame(cbind(square$c1,square$c2))
#' res1 <- DecTree( square$Class4, Xc, maxdepth=3, print=1 )
#' pred <- predict_dt( Xc, res1$node )
#' Print(pred$yhat, pred$prob)
#'
#' @details
#' \code{obj$node} に記録されている、各個体を Left と Right に分類する規則を
#' \code{X} の各行に適用し、個体を終端ノードに割り当てる。
#'
#' \code{X} にカテゴリ変数を持つ新しい個体が含まれる場合、
#' \code{node} を作成したトレーニングデータと同じ水準を用いて factor 化されて
#' いなければならない。
#'
#' @return  A list of: \cr
#' yhat: 予測値からなるベクトル \cr
#' prob: クラスの生起確率からなる行列
#' Node: 個体が所属する葉ノードの番号
#'
#'
#'
#' # @keywords internal
#' @docType package
#' @name predict_dt_JPH
NULL
