% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Divide.R
\name{Divide}
\alias{Divide}
\title{Divide a set of objects into two homogeneous sets}
\usage{
Divide(
  ys,
  Xs,
  Ys = NULL,
  impfunc,
  S,
  method = 1,
  ncatx = 0,
  app = 0,
  maxapp = 10,
  maxncut = 50,
  levelsy = NULL,
  levelsX = NULL
)
}
\arguments{
\item{ys}{Criterion variable vector}

\item{Xs}{Regressor matrix}

\item{Ys}{The dichotomized criterion matrix for \code{method=4}}

\item{impfunc}{impurity function}

\item{S}{Index vector indicating the original location of
the rows of ys and X. \cr
(ys, Xs, Ys, S) have the same # of rows or of the same length.}

\item{method}{Treatment of the categorical regressor variable. \cr
= 0 to dummy expand the categorical regressor, \cr
= 1 to use the first canonical varialbe, \cr
= 2 to use up to the 2nd canonical variables and their sum and difference,\cr
= 3 to use one-versus-rest dichotomization. \cr
= 4 to use dichotomization of the criterion variable on the basis of
all possible bipartitions of the levels of the criterion variable.}

\item{ncatx}{Vector consisting of the # of cagegories of the regressors}

\item{app}{= 0 not to use app (all possible partitions) \cr
= 1 to use app when ncaty >= 3 and ncatx >= 3 \cr
= 9 to use app awlays for categorical predictors.}

\item{maxapp}{Maximum # of categories of the regressor variables
for which app is used.}

\item{maxncut}{Maximum # of cut point (threshold) candidate}

\item{levelsy}{# of levels of the criterion}

\item{levelsx}{a list of the # of levels of the regressors}
}
\value{
A list consisting of the following:
\preformatted{
j:         the variable number used to divide the set
threshold: the threshold of variable j when it is continuous, or NA.
valxj: the set of values of nominal variable j to be classified as left
valxjR: the set of values of nominal variable j to be classified as right
       Note that these are numeric variables, not factors.
k:     quantified variable number used or 0
nqx:   # of unique quantified variables
locLL and locRR: the location of obs in 1:nrow(Xs) to be classficed
left:  the set of observations classified as left
right: the set of observations classified as right
left.score:  The nobs weighted impurity measure of left set
right.score: The nobs weighted impurity measure of right set
score:       The sum of the above two.
}
}
\description{
This function divides a given set of objects into two subsets
so that the weighted sum of the impurity measures of the subsets
are minimized using a greedy algorithm with Depth-First Search (DFS). \cr
Japanese help file: \link[lazy.tree]{Divide_JPH}
}
\details{
\code{ncat=0} or \code{ncat=1} means the variable is continuous, \cr
 \code{ncat=2} means the variable is binary, \cr
 \code{ncat >= 3} means the variable is polytomous.
}
\examples{
Xc <- data.frame(x1=as.factor(square$x1),x2=as.factor(square$x2))
Divide( square$Class4, Xc, impfunc=gini, S=1:nrow(Xc), method=1
      , ncatx=c(7,5), app=0 )
Divide( square$Class4, Xc, impfunc=gini, S=1:nrow(Xc), app=9
      , ncatx=c(7,5) )


}
