% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/DivideM.R
\name{DivideM}
\alias{DivideM}
\title{Divide a set of objects into two homogeneous sets with resampling}
\usage{
DivideM(
  ys,
  Xs,
  Ys = NULL,
  impfunc,
  S,
  method = 1,
  ncatx = 0,
  app = 0,
  maxapp = 10,
  maxncut = 50,
  levelsy = NULL,
  levelsX = NULL,
  majestic = 3,
  nrepM = 50,
  psampleM = 100,
  rf = 1,
  nxvarM = if (!is.null(ys) && !is.factor(ys)) max(floor(ncol(Xs)/3), 1) else
    floor(sqrt(ncol(Xs))),
  minLeftM = 0.5,
  maxRightM = 0.5,
  r = 0,
  debug = 0
)
}
\arguments{
\item{ys}{Criterion variable vector}

\item{Xs}{Regressor matrix}

\item{Ys}{The dichotomized criterion matrix for \code{method=4}}

\item{impfunc}{impurity function}

\item{S}{Index vector indicating the original location of
the rows of ys and X.}

\item{method}{Treatment of the categorical regressor variable. \cr
= 0 to dummy expand the categorical regressor, \cr
= 1 to use the first canonical varialbe, \cr
= 2 to use up to the 2nd canonical variables and their sum and
difference,\cr
= 3 to use one-versus-rest dichotomization. \cr
= 4 to use dichotomization of the criterion variable on the basis of
all possible bipartitions of the levels of the criterion variable.}

\item{ncatx}{Vector consisting of the # of cagegories of the regressors}

\item{app}{= 0 not to use app (all possible partitions) \cr
= 1 to use app when ncaty >= 3 and ncatx >= 3 \cr
= 9 to use app awlays for categorical predictors.}

\item{maxapp}{Maximum # of categories of the regressor variables
for which app is used.}

\item{maxncut}{Maximum # of cut point (threshold) candidate}

\item{levelsy}{# of levels of the criterion}

\item{majestic}{> 0 to use within node resampling: \cr
= 1 to use modal splitting variable \cr
= 2 to use binary LR to determine J and predict ys from J\cr
= 3 to use binary LR to determine J\cr
= 4 to use continuous LR\cr
= 5 to use logit of continuous LR}

\item{nrepM}{# of divisions to try for majestic tree}

\item{psampleM}{percentage of the sample for majestic tree}

\item{rf}{= 0 not to sample regressor variables}

\item{nxvarM}{# of variables to sample for majestic tree (Random Forest)}

\item{minLeftM}{minimum proportion of x values to be classified as Left}

\item{maxRightM}{maximum proportion of x values to be classified as Right}

\item{r}{node number}

\item{debug}{= 1 to print intermediate result}

\item{levelsx}{a list of the # of levels of the regressors}
}
\value{
A list consisting of the following:
\preformatted{
j:         the variable number used to divide the set
threshold: the threshold of variable j when it is continuous
valxj: the set of values of nominal variable j to be classified as left.
       Note that this is a numeric variable, not a factor.
k:     quantified variable number used or 0
nqx:   # of unique quantified variables
left:  the set of observations classified as left
right: the set of observations classified as right
left.score:  The nobs weighted impurity measure of left set
right.score: The nobs weighted impurity measure of right set
score:       The sum of the above two.
}
}
\description{
This function searches the average division of a given subset
by resmpling the subset.  \cr
Japanese help file: \link[lazy.tree]{DivideM_JPH}
}
\details{
\code{ncat=0} or \code{ncat=1} means the variable is continuous, \cr
 \code{ncat=2} means the variable is binary, \cr
 \code{ncat >= 3} means the variable is polytomous.
}
\examples{

N=500
Xc=data.frame(x1=as.factor(square3$x1), x2=square3$x2)
yc=as.factor(square3$y)
Xc=Xc[1:N,]
yc=yc[1:N]
S=1:N
maxncatx=max( apply( Xc, 2, function(x){length(unique(x))} ) )

ncaty=length(levels(yc))

  id=gen01pat( ncaty, sort=-2, partition=1 ) == 1  # logical matrix
  npart=nrow(id)
  uy=unique(yc)
  Yc=matrix(0,N,npart)
  for(k in 1:npart ){
    Yc[,k]=yc \%in\% uy[id[k,]]
  }

  nx=ncol(Xc)
  ncatx=rep(0,nx)
  for( j in 1:nx ){
    if( is.factor(Xc[,j]) ) ncatx[j]=length(levels(Xc[,j]))
  }

res00=DivideM( yc, Xc, Y=Yc, impfunc=entropy, S, method=1, ncatx=ncatx
              , app=0, maxapp=10, maxncut=50
              , levelsy=NULL, levelsX=NULL
              , psampleM=100, nrepM=20, r=0 )


}
