% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summary_dt_JPH.R
\docType{package}
\name{summary_dt_JPH}
\alias{summary_dt_JPH}
\title{決定木の結果の要約}
\usage{
summary_dt( obj, y, X=NULL, yhat=NULL, prob=NULL
                  , minp=1e-4, nleaf=0, print=1
                  , outpred=0, title="" )
}
\arguments{
\item{obj}{DecTree クラスオブジェクトまたは node のリスト.}

\item{y}{基準変数}

\item{X}{新しい説明変数行列}

\item{yhat}{予測値のベクトル}

\item{prob}{確率の行列}

\item{minp}{確率の最小値}

\item{nleaf}{obj が node の場合の葉の数}

\item{print}{= 0 出力を抑制する}

\item{outpred}{= 1 予測値を出力する}

\item{title}{タイトル文字列}
}
\value{
以下の要素からなるリスト:
\preformatted{
\code{y} がカテゴリカルな場合
nleaf:  葉の数
Tab:       混同行列 confusion matrix: (row=true, col=predicted)
margin: 周辺度数
Gini: gini 係数
mllh: 多項分布を仮定したときの対数尤度
nparam, aic, bic:
tprecision: total precision
macroF1: macro F1
weightedF1: 重み付き F1
SCT: 各水準ごとの accuracy, precision, recall, specificity, and F1-score

\code{y} が連続量の場合
nleaf:  葉の数
corr:  \code{y} と予測値の間の相関係数
}
}
\description{
決定木の結果（class DecTree object）またはそれと新しい説明変数行列 \code{X}
が与えられた場合に、様々な適合度指標を計算する。\cr
English help file: \link[lazy.tree]{summary_dt}
}
\details{
データセット \code{(y,X)} を用いて統計量を計算するが、
\code{X} が与えられていない場合には、\code{obj} に含まれる \code{y} の
予測値が用いられる。
\code{X} が与えたれた場合には、\code{predict_dt} により
\code{y} の予測値が計算される。
したがって、\code{obj} は \code{y} を含んでいないので、
いずれにしても \code{y} は必要となる。

\code{yhat} が与えられた場合には \code{(y,yhat)} から統計量を計算する。
}
\examples{
Xc <- as.data.frame(cbind(square$c1,square$c2))
res1 <- DecTree( square$Class4, Xc, maxdepth=3, print=1 )
# temp と temp2 は同じになるはず。
# X は与えない。
temp <- summary_dt( res1, square$Class4, title="square" )
# X として obj に含まれるものと同じものを与える。
temp2 <- summary_dt( res1, square$Class4, Xc, title="square" )
# y と yhat のみ、prob なし
temp22 <- summary_dt( yhat=res1$yhat, y=square$Class4)
# 新しい X を与える。
temp3 <- summary_dt( res1, square$Class4[1:10], Xc[1:10,], title="square" )

# @keywords internal
}
